@@ -26,7 +26,6 @@ from .literals import (
     StoreFormatType,
     TaskStatusType,
     WorkflowEngineType,
-    WorkflowTypeType,
 )
 from .paginator import (
     ListAnnotationImportJobsPaginator,
@@ -591,7 +590,7 @@ class OmicsClient(BaseClient):
         *,
         id: str,
         export: Sequence[Literal["DEFINITION"]] = ...,
-        type: WorkflowTypeType = ...
+        type: Literal["PRIVATE"] = ...
     ) -> GetWorkflowResponseTypeDef:
         """
         Gets information about a workflow.
@@ -832,7 +831,7 @@ class OmicsClient(BaseClient):
         maxResults: int = ...,
         name: str = ...,
         startingToken: str = ...,
-        type: WorkflowTypeType = ...
+        type: Literal["PRIVATE"] = ...
     ) -> ListWorkflowsResponseTypeDef:
         """
         Retrieves a list of workflows.
@@ -932,7 +931,7 @@ class OmicsClient(BaseClient):
         storageCapacity: int = ...,
         tags: Mapping[str, str] = ...,
         workflowId: str = ...,
-        workflowType: WorkflowTypeType = ...
+        workflowType: Literal["PRIVATE"] = ...
     ) -> StartRunResponseTypeDef:
         """
         Starts a run.
