@@ -49,11 +49,12 @@ Usage::
     list_workflows_paginator: ListWorkflowsPaginator = client.get_paginator("list_workflows")
     ```
 """
+import sys
 from typing import Generic, Iterator, Sequence, TypeVar
 
 from botocore.paginate import PageIterator, Paginator
 
-from .literals import TaskStatusType, WorkflowTypeType
+from .literals import TaskStatusType
 from .type_defs import (
     ActivateReadSetFilterTypeDef,
     ExportReadSetFilterTypeDef,
@@ -86,6 +87,12 @@ from .type_defs import (
     SequenceStoreFilterTypeDef,
 )
 
+if sys.version_info >= (3, 9):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
+
 __all__ = (
     "ListAnnotationImportJobsPaginator",
     "ListAnnotationStoresPaginator",
@@ -405,7 +412,7 @@ class ListWorkflowsPaginator(Paginator):
         self,
         *,
         name: str = ...,
-        type: WorkflowTypeType = ...,
+        type: Literal["PRIVATE"] = ...,
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListWorkflowsResponseTypeDef]:
         """
