@@ -42,7 +42,6 @@ from .literals import (
     TaskStatusType,
     WorkflowEngineType,
     WorkflowStatusType,
-    WorkflowTypeType,
 )
 
 if sys.version_info >= (3, 9):
@@ -895,7 +894,7 @@ _OptionalGetWorkflowRequestRequestTypeDef = TypedDict(
     "_OptionalGetWorkflowRequestRequestTypeDef",
     {
         "export": Sequence[Literal["DEFINITION"]],
-        "type": WorkflowTypeType,
+        "type": Literal["PRIVATE"],
     },
     total=False,
 )
@@ -1241,7 +1240,7 @@ ListWorkflowsRequestRequestTypeDef = TypedDict(
         "maxResults": int,
         "name": str,
         "startingToken": str,
-        "type": WorkflowTypeType,
+        "type": Literal["PRIVATE"],
     },
     total=False,
 )
@@ -1255,7 +1254,7 @@ WorkflowListItemTypeDef = TypedDict(
         "id": str,
         "name": str,
         "status": WorkflowStatusType,
-        "type": WorkflowTypeType,
+        "type": Literal["PRIVATE"],
     },
     total=False,
 )
@@ -1327,7 +1326,7 @@ _OptionalStartRunRequestRequestTypeDef = TypedDict(
         "storageCapacity": int,
         "tags": Mapping[str, str],
         "workflowId": str,
-        "workflowType": WorkflowTypeType,
+        "workflowType": Literal["PRIVATE"],
     },
     total=False,
 )
@@ -1819,7 +1818,7 @@ GetRunResponseTypeDef = TypedDict(
         "storageCapacity": int,
         "tags": Dict[str, str],
         "workflowId": str,
-        "workflowType": WorkflowTypeType,
+        "workflowType": Literal["PRIVATE"],
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -2033,7 +2032,7 @@ GetWorkflowResponseTypeDef = TypedDict(
         "statusMessage": str,
         "storageCapacity": int,
         "tags": Dict[str, str],
-        "type": WorkflowTypeType,
+        "type": Literal["PRIVATE"],
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
@@ -2454,7 +2453,7 @@ _OptionalGetWorkflowRequestWorkflowActiveWaitTypeDef = TypedDict(
     "_OptionalGetWorkflowRequestWorkflowActiveWaitTypeDef",
     {
         "export": Sequence[Literal["DEFINITION"]],
-        "type": WorkflowTypeType,
+        "type": Literal["PRIVATE"],
         "WaiterConfig": WaiterConfigTypeDef,
     },
     total=False,
@@ -2812,7 +2811,7 @@ ListWorkflowsRequestListWorkflowsPaginateTypeDef = TypedDict(
     "ListWorkflowsRequestListWorkflowsPaginateTypeDef",
     {
         "name": str,
-        "type": WorkflowTypeType,
+        "type": Literal["PRIVATE"],
         "PaginationConfig": PaginatorConfigTypeDef,
     },
     total=False,
